@@ -119,3 +119,33 @@ path = path.replace('\\' , '/')
 feather.write_dataframe(raw_imp, "demo_filled.feather")
 
 os.getcwd()
+
+#%% for resubmission
+
+intensities_raw = feather.read_dataframe("C:/Users/weidner.leopold/Documents/10_Publications/02_Online_Roasting/data-RiedFresh/2023-01-23-example_dataset-resubmission.feather")
+annotation_metadata = feather.read_dataframe("C:/Users/weidner.leopold/Documents/10_Publications/02_Online_Roasting/data-RiedFresh/2023-01-23-example__metadata2-resubmission.feather")
+
+IDs = annotation_metadata["ID"]
+intensities_raw = intensities_raw.drop("ID", axis = 1)
+
+raw_imp = dbdi.impute_intensities(intensities_raw, method = "linear")
+
+ca = pd.DataFrame({'deltamz': [47.984744, 63.979658], 'motive': ["O3", "O4"]})
+
+adducts095 =  dbdi.identify_adducts(raw_imp, annotation_metadata["ThMass.Ion"], 
+                         custom_adducts = ca, method = "spearman", threshold = 0.95, mass_error = 5)
+
+searchres4plotting = {k:len(v) for k, v in adducts095.items()}
+
+
+
+
+#%% propose adducts
+propose_adducts(ID = 55, df = raw_imp, 
+                masses = annotation_metadata["ThMass.Ion"],
+                method = "pearson", threshold = 0.95, 
+                mass_error = 0.005)
+  
+    
+  
+    
